# Gencharts

Generate html charts with Altair

   ```bash
   pip install gencharts
   ```

## API

`serialize`: serialize to an Altair chart object from either a pandas dataframe, a dictionnary or an Altair Data object

`html`: generate html and optionally write it to a file

## Todo

- [ ] Better documentation